// Model.hpp
//
// Copyright 2011-2012 Roan Trail, Inc.
//
// This file is part of Kinetophone.
//
// Kinetophone is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published
// by the Free Software Foundation, either version 2 of the License,
// or (at your option) any later version.
//
// Kinetophone is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.  You should have received
// a copy of the GNU General Public License along with Kinetophone. If
// not, see <http://www.gnu.org/licenses/>.

#ifndef MODEL_HPP_
#define MODEL_HPP_

namespace Roan_trail
{
  class Model
  {
  public:
    Model() {}
    virtual ~Model() {}
  private:
    // prevent compiler from generating
    Model(const Model& m);
    Model& operator=(const Model& m);
  };
}

#endif // MODEL_HPP_
